@@ -308,6 +308,7 @@ class Node(BaseModel, T.Generic[InsertType, PatchType]):
         cls: T.Type[ThisNodeType],
         insert: InsertType,
         given_resolver: "ResolverType" = None,
+        merge_resolver: bool = True,
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
         upsert_given_conflict_on: str = None,
@@ -317,6 +318,8 @@ class Node(BaseModel, T.Generic[InsertType, PatchType]):
         """Turn insert into a string with variables"""
         if not given_resolver:
             given_resolver = cls.GraphORM.resolver_type()
+        if merge_resolver:
+            given_resolver.merge()
         cls.validate_upsert_fields(
             upsert_given_conflict_on=upsert_given_conflict_on,
             return_conflicting_model_on=return_conflicting_model_on,
@@ -470,11 +473,14 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
     async def delete(
         self,
         given_resolver: "ResolverType" = None,
+        merge_resolver: bool = True,
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
     ) -> None:
         if not given_resolver:
             given_resolver = self._used_resolver
+        if merge_resolver:
+            given_resolver.merge()
         given_resolver.clear_top_level_filters_and_variables()
         given_resolver.filter(filter_str=".id = <uuid>$id", variables={"id": self.id})
         if batch:
@@ -683,6 +689,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         cls: T.Type[ThisNodeType],
         patch: PatchType,
         resolver_with_filter: "ResolverType",
+        merge_resolver: bool = True,
         set_strs: T.List[str] = None,
         only_one: bool = True,
         update_last_updated: bool = False,
@@ -696,6 +703,8 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         set_links_d = make_set_links_d(model=patch, model_d=update_d)
         if not update_d and not set_links_d:
             raise NodeException("No update registered.")
+        if merge_resolver:
+            resolver_with_filter.merge()
         node_or_nodes = await cls._update(
             resolver=resolver_with_filter,
             update_d=update_d,
@@ -712,6 +721,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
     async def update(
         self,
         given_resolver: "ResolverType" = None,
+        merge_resolver: bool = True,
         error_if_no_update: bool = False,
         set_links_d: T.Dict[str, "Resolver"] = None,
         batch: Batch = None,
@@ -720,6 +730,8 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         """set_links_d -> {people_i_follow += (select Person filter .first_name = <str>first_name)}"""
         if not given_resolver:
             given_resolver = self._used_resolver
+        if merge_resolver:
+            given_resolver.merge()
         update_d = self.build_update_d()
         if not update_d:
             message = f"No update registered for {self.id=}."
