@@ -647,3 +647,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         pre_merge_resolver = self.copy(deep=True)
         self._pre_merge_resolver = pre_merge_resolver
         self._nested_resolvers = merge_nested_resolver(self.nested_resolvers)
+
+    def debug_nested_resolvers(self) -> None:
+        debug(self._nested_resolvers)
+        for edge, resolvers in self._nested_resolvers.d.items():
+            print(f"{edge=}")
+            for r in resolvers:
+                r.debug_nested_resolvers()
